@@ -1,16 +1,19 @@
 package access_keys
 
 import (
+	"context"
 	"strings"
 
-	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/credentials"
-	"github.com/aws/aws-sdk-go/aws/session"
-	"github.com/aws/aws-sdk-go/service/sns"
+	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/aws/aws-sdk-go-v2/aws/middleware"
+	"github.com/aws/aws-sdk-go-v2/config"
+	"github.com/aws/aws-sdk-go-v2/credentials"
+	"github.com/aws/aws-sdk-go-v2/service/sns"
+	"github.com/trufflesecurity/trufflehog/v3/pkg/common"
 )
 
-const thinkstMessage = "This is an AWS canary token generated at canarytokens.org, and was not set off; learn more here: https://trufflesecurity.com/canaries"
-const thinkstKnockoffsMessage = "This is an off brand AWS Canary inspired by canarytokens.org. It wasn't set off; learn more here: https://trufflesecurity.com/canaries"
+const thinkstMessage = "This is an AWS canary token generated at canarytokens.org."
+const thinkstKnockoffsMessage = "This is an off brand AWS Canary inspired by canarytokens.org."
 
 var (
 	thinkstCanaryList = map[string]struct{}{
@@ -44,21 +47,24 @@ var (
 	}
 )
 
-func (s scanner) verifyCanary(resIDMatch, resSecretMatch string) (bool, string, error) {
+func (s scanner) verifyCanary(ctx context.Context, resIDMatch, resSecretMatch string) (bool, string, error) {
 	// Prep AWS Creds for SNS
-	sess := session.Must(session.NewSession(&aws.Config{
-		Region: aws.String("us-east-1"), // any region seems to work
-		Credentials: credentials.NewStaticCredentials(
-			resIDMatch,
-			resSecretMatch,
-			"",
+	cfg, err := config.LoadDefaultConfig(ctx,
+		config.WithRegion(region),
+		config.WithHTTPClient(s.getAWSBuilableClient()),
+		config.WithCredentialsProvider(
+			credentials.NewStaticCredentialsProvider(resIDMatch, resSecretMatch, ""),
 		),
-		HTTPClient: s.verificationClient,
-	}))
-	svc := sns.New(sess)
+	)
+	if err != nil {
+		return false, "", err
+	}
+	svc := sns.NewFromConfig(cfg, func(o *sns.Options) {
+		o.APIOptions = append(o.APIOptions, middleware.AddUserAgentKeyValue("User-Agent", common.UserAgent()))
+	})
 
 	// Prep vars and Publish to SNS
-	_, err := svc.Publish(&sns.PublishInput{
+	_, err = svc.Publish(ctx, &sns.PublishInput{
 		Message:     aws.String("foo"),
 		PhoneNumber: aws.String("1"),
 	})
@@ -69,7 +75,7 @@ func (s scanner) verifyCanary(resIDMatch, resSecretMatch string) (bool, string,
 		return true, arn, nil
 	} else if strings.Contains(err.Error(), "does not match the signature you provided") {
 		return false, "", nil
-	} else if strings.Contains(err.Error(), "status code: 403") {
+	} else if strings.Contains(err.Error(), "status code: 403") || strings.Contains(err.Error(), "InvalidClientTokenId") {
 		return false, "", nil
 	} else {
 		return false, "", err
