@@ -42,15 +42,9 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 	spellMatches := spellPat.FindAllStringSubmatch(dataStr, -1)
 
 	for _, spellMatch := range spellMatches {
-		if len(spellMatch) != 2 {
-			continue
-		}
 		resSpellMatch := strings.TrimSpace(spellMatch[1])
 
 		for _, match := range matches {
-			if len(match) != 2 {
-				continue
-			}
 			resMatch := strings.TrimSpace(match[1])
 
 			s1 := detectors.Result{
