@@ -50,7 +50,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 
 	matches := keyPat.FindAllString(dataStr, -1)
 	for _, match := range matches {
-		token := normalize(match)
+		token := Normalize(match)
 		if len(token) < 64 {
 			continue
 		}
@@ -66,7 +66,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 		parsedKey, err := ssh.ParseRawPrivateKey([]byte(token))
 		if err != nil && strings.Contains(err.Error(), "private key is passphrase protected") {
 			s1.ExtraData["encrypted"] = "true"
-			parsedKey, passphrase, err = crack([]byte(token))
+			parsedKey, passphrase, err = Crack([]byte(token))
 			if err != nil {
 				s1.SetVerificationError(err, token)
 				continue
@@ -88,14 +88,14 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			var (
 				wg                 sync.WaitGroup
 				extraData          = newExtraData()
-				verificationErrors = newVerificationErrors()
+				verificationErrors = NewVerificationErrors(3)
 			)
 
 			// Look up certificate information.
 			wg.Add(1)
 			go func() {
 				defer wg.Done()
-				data, err := lookupFingerprint(ctx, fingerprint, s.IncludeExpired)
+				data, err := lookupFingerprintCertificateUrls(ctx, fingerprint, s.IncludeExpired)
 				if err == nil {
 					if data != nil {
 						extraData.Add("certificate_urls", strings.Join(data.CertificateURLs, ", "))
@@ -109,7 +109,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			wg.Add(1)
 			go func() {
 				defer wg.Done()
-				user, err := verifyGitHubUser(ctx, parsedKey)
+				user, err := VerifyGitHubUser(ctx, parsedKey)
 				if err != nil && !errors.Is(err, errPermissionDenied) {
 					verificationErrors.Add(err)
 				}
@@ -122,7 +122,7 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 			wg.Add(1)
 			go func() {
 				defer wg.Done()
-				user, err := verifyGitLabUser(ctx, parsedKey)
+				user, err := VerifyGitLabUser(ctx, parsedKey)
 				if err != nil && !errors.Is(err, errPermissionDenied) {
 					verificationErrors.Add(err)
 				}
@@ -137,11 +137,16 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 				for k, v := range extraData.data {
 					s1.ExtraData[k] = v
 				}
+
+				// enabled th
+				s1.AnalysisInfo = map[string]string{
+					"token": token,
+				}
 			} else {
 				s1.ExtraData = nil
 			}
-			if len(verificationErrors.errors) > 0 {
-				s1.SetVerificationError(fmt.Errorf("verification failures: %s", strings.Join(verificationErrors.errors, ", ")), token)
+			if len(verificationErrors.Errors) > 0 {
+				s1.SetVerificationError(fmt.Errorf("verification failures: %s", strings.Join(verificationErrors.Errors, ", ")), token)
 			}
 		}
 
@@ -164,19 +169,15 @@ type result struct {
 	GitHubUsername  string
 }
 
-func lookupFingerprint(ctx context.Context, publicKeyFingerprintInHex string, includeExpired bool) (*result, error) {
-	req, err := http.NewRequestWithContext(ctx, "GET", fmt.Sprintf("https://keychecker.trufflesecurity.com/fingerprint/%s", publicKeyFingerprintInHex), nil)
-	if err != nil {
-		return nil, err
-	}
-	res, err := client.Do(req)
-	if err != nil {
-		return nil, err
-	}
-	defer res.Body.Close()
-
-	results := DriftwoodResult{}
-	err = json.NewDecoder(res.Body).Decode(&results)
+func lookupFingerprintCertificateUrls(
+	ctx context.Context,
+	publicKeyFingerprintInHex string,
+	includeExpired bool,
+) (*result, error) {
+	results, err := LookupFingerprint(
+		ctx,
+		publicKeyFingerprintInHex,
+	)
 	if err != nil {
 		return nil, err
 	}
@@ -201,10 +202,39 @@ func lookupFingerprint(ctx context.Context, publicKeyFingerprintInHex string, in
 	return data, nil
 }
 
+func LookupFingerprint(ctx context.Context, publicKeyFingerprintInHex string) (*DriftwoodResult, error) {
+	req, err := http.NewRequestWithContext(ctx, "GET", fmt.Sprintf("https://keychecker.trufflesecurity.com/fingerprint/%s", publicKeyFingerprintInHex), nil)
+	if err != nil {
+		return nil, err
+	}
+	res, err := client.Do(req)
+	if err != nil {
+		return nil, err
+	}
+	defer res.Body.Close()
+
+	results := DriftwoodResult{}
+	err = json.NewDecoder(res.Body).Decode(&results)
+	if err != nil {
+		return nil, err
+	}
+	return &results, nil
+}
+
 type DriftwoodResult struct {
 	CertificateResults []struct {
+		Domains                []string  `json:",omitempty"`
 		CertificateFingerprint string    `json:"CertificateFingerprint"`
 		ExpirationTimestamp    time.Time `json:"ExpirationTimestamp"`
+		IssuerName             string    `json:",omitempty"` // CA information
+		SubjectName            string    `json:",omitempty"` // Certificate subject
+		IssuerOrganization     []string  `json:",omitempty"` // CA organization(s)
+		SubjectOrganization    []string  `json:",omitempty"` // Subject organization(s)
+		KeyUsages              []string  `json:",omitempty"` // e.g., ["DigitalSignature", "KeyEncipherment"]
+		ExtendedKeyUsages      []string  `json:",omitempty"` // e.g., ["ServerAuth", "ClientAuth"]
+		SubjectKeyID           string    `json:",omitempty"` // hex encoded
+		AuthorityKeyID         string    `json:",omitempty"` // hex encoded
+		SerialNumber           string    `json:",omitempty"` // hex encoded
 	} `json:"CertificateResults"`
 	GitHubSSHResults []struct {
 		Username string `json:"Username"`
@@ -228,20 +258,20 @@ func (e *extraData) Add(key string, value string) {
 	e.mutex.Unlock()
 }
 
-type verificationErrors struct {
+type VerificationErrors struct {
 	mutex  sync.Mutex
-	errors []string
+	Errors []string
 }
 
-func newVerificationErrors() *verificationErrors {
-	return &verificationErrors{
-		errors: make([]string, 0, 3),
+func NewVerificationErrors(capacity int) *VerificationErrors {
+	return &VerificationErrors{
+		Errors: make([]string, 0, capacity),
 	}
 }
 
-func (e *verificationErrors) Add(err error) {
+func (e *VerificationErrors) Add(err error) {
 	e.mutex.Lock()
-	e.errors = append(e.errors, err.Error())
+	e.Errors = append(e.Errors, err.Error())
 	e.mutex.Unlock()
 }
 
