@@ -42,15 +42,9 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 	secretMatches := secretPat.FindAllStringSubmatch(dataStr, -1)
 
 	for _, clientMatch := range clientMatches {
-		if len(clientMatch) != 2 {
-			continue
-		}
 		resClient := strings.TrimSpace(clientMatch[1])
 
 		for _, secretMatch := range secretMatches {
-			if len(secretMatch) != 2 {
-				continue
-			}
 			resSecret := strings.TrimSpace(secretMatch[1])
 
 			s1 := detectors.Result{
