@@ -23,8 +23,9 @@ const (
 var (
 	// NOTE: This is a temporary workaround for |openArchive| incrementing depth twice per archive.
 	// See: https://github.com/trufflesecurity/trufflehog/issues/2942
-	maxDepth = 5 * 2
-	maxSize  = 2 << 30 // 2 GB
+	maxDepth   = 5 * 2
+	maxSize    = 2 << 30 // 2 GB
+	maxTimeout = time.Duration(60) * time.Second
 )
 
 // SetArchiveMaxSize sets the maximum size of the archive.
@@ -33,6 +34,9 @@ func SetArchiveMaxSize(size int) { maxSize = size }
 // SetArchiveMaxDepth sets the maximum depth of the archive.
 func SetArchiveMaxDepth(depth int) { maxDepth = depth }
 
+// SetArchiveMaxTimeout sets the maximum timeout for the archive handler.
+func SetArchiveMaxTimeout(timeout time.Duration) { maxTimeout = timeout }
+
 // archiveHandler is a handler for common archive files that are supported by the archiver library.
 type archiveHandler struct{ *defaultHandler }
 
@@ -138,7 +142,7 @@ func (h *archiveHandler) openArchive(
 		}
 		defer compReader.Close()
 
-		rdr, err := newFileReader(compReader)
+		rdr, err := newFileReader(ctx, compReader)
 		if err != nil {
 			if errors.Is(err, ErrEmptyReader) {
 				ctx.Logger().V(5).Info("empty reader, skipping file")
@@ -226,7 +230,7 @@ func (h *archiveHandler) extractorHandler(dataOrErrChan chan DataOrErr) func(con
 			}
 		}()
 
-		rdr, err := newFileReader(f)
+		rdr, err := newFileReader(ctx, f)
 		if err != nil {
 			if errors.Is(err, ErrEmptyReader) {
 				lCtx.Logger().V(5).Info("empty reader, skipping file")
