@@ -275,6 +275,24 @@ func TestSource_Validate(t *testing.T) {
 			},
 			wantErrCount: 2,
 		},
+
+		{
+			name: "could not compile include glob(s)",
+			connection: &sourcespb.GitLab{
+				Credential: &sourcespb.GitLab_Token{
+					Token: token,
+				},
+				IncludeRepos: []string{
+					"tes1188/*-gitlab",
+					"[",    // glob doesn't compile
+					"[a-]", // glob doesn't compile
+				},
+				IgnoreRepos: []string{
+					"[",
+				},
+			},
+			wantErrCount: 3,
+		},
 		{
 			name: "repositories do not exist or are not accessible",
 			connection: &sourcespb.GitLab{
@@ -444,3 +462,112 @@ func TestSource_Chunks_TargetedScan(t *testing.T) {
 		})
 	}
 }
+
+func TestSource_InclusionGlobbing(t *testing.T) {
+	ctx, cancel := context.WithTimeout(context.Background(), time.Second*5)
+	defer cancel()
+
+	secret, err := common.GetTestSecret(ctx)
+	if err != nil {
+		t.Fatal(fmt.Errorf("failed to access secret: %v", err))
+	}
+
+	token := secret.MustGetField("GITLAB_TOKEN")
+
+	tests := []struct {
+		name             string
+		connection       *sourcespb.GitLab
+		wantReposScanned int
+		wantErrCount     int
+	}{
+		{
+			name: "Get all Repos",
+			connection: &sourcespb.GitLab{
+				Credential: &sourcespb.GitLab_Token{
+					Token: token,
+				},
+				IncludeRepos: []string{"*"},
+				IgnoreRepos:  nil,
+			},
+			wantReposScanned: 6,
+			wantErrCount:     0,
+		},
+		{
+			name: "Ignore testy repo, include all others",
+			connection: &sourcespb.GitLab{
+				Credential: &sourcespb.GitLab_Token{
+					Token: token,
+				},
+				IncludeRepos: []string{"*"},
+				IgnoreRepos:  []string{"*testy*"},
+			},
+			wantReposScanned: 5,
+			wantErrCount:     0,
+		},
+		{
+			name: "Ignore all repos",
+			connection: &sourcespb.GitLab{
+				Credential: &sourcespb.GitLab_Token{
+					Token: token,
+				},
+				IncludeRepos: nil,
+				IgnoreRepos:  []string{"*"},
+			},
+			wantReposScanned: 0,
+			wantErrCount:     0,
+		},
+		{
+			name: "Ignore all repos, but glob doesn't compile",
+			connection: &sourcespb.GitLab{
+				Credential: &sourcespb.GitLab_Token{
+					Token: token,
+				},
+				IncludeRepos: []string{
+					"[",    // glob doesn't compile
+					"[a-]", // glob doesn't compile
+				},
+				IgnoreRepos: []string{
+					"*", // ignore all repos
+					"[", // glob doesn't compile
+				},
+			},
+			wantReposScanned: 0,
+			wantErrCount:     3,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+
+			src := &Source{}
+			conn, err := anypb.New(tt.connection)
+			assert.NoError(t, err)
+
+			err = src.Init(ctx, tt.name, 0, 0, false, conn, 1)
+			assert.NoError(t, err)
+
+			// Query GitLab for the list of configured repos.
+			var repos []string
+			visitor := sources.VisitorReporter{
+				VisitUnit: func(ctx context.Context, unit sources.SourceUnit) error {
+					id, _ := unit.SourceUnitID()
+					repos = append(repos, id)
+					return nil
+				},
+			}
+			apiClient, err := src.newClient()
+			assert.NoError(t, err)
+
+			var errs []error
+			ignoreRepo := buildIgnorer(ctx, src.includeRepos, src.ignoreRepos, func(err error, pattern string) {
+				errs = append(errs, err)
+			})
+			err = src.getAllProjectRepos(ctx, apiClient, ignoreRepo, visitor)
+			assert.NoError(t, err)
+
+			assert.Equal(t, tt.wantErrCount, len(errs))
+			assert.Equal(t, tt.wantReposScanned, len(repos))
+
+		})
+	}
+}
